@@ -70,15 +70,19 @@ def aggregate_spark_int(data, n_jobs):
 			for col in _data.columns
 		])
 
-	def _union_all(_data_list):
-		return reduce(SparkDF.unionAll, _data_list)
+	if n_jobs == 1:
+		return _aggregate_spark_int(data)
 
-	data_list = data.randomSplit([1.0] * n_jobs)
-	pool = ThreadPool(n_jobs)
-	result_list = pool.map(_aggregate_spark_int, data_list)
-	union = _union_all(result_list)
+	else:
+		def _union_all(_data_list):
+			return reduce(SparkDF.unionAll, _data_list)
 
-	return _aggregate_spark_int(union)
+		data_list = data.randomSplit([1.0] * n_jobs)
+		pool = ThreadPool(n_jobs)
+		result_list = pool.map(_aggregate_spark_int, data_list)
+		union = _union_all(result_list)
+
+		return _aggregate_spark_int(union)
 
 
 def concat_pandas_columns(data, name='concat_column', sep='|', return_data=False):
